@@ -47,8 +47,15 @@ class Decorators:
                 args = f_args.values()
                 resp = func(*args, **kwargs)
                 if response_type and resp.status_code // 100 == 2:
+                    untyped = resp.json()
                     try:
-                        resp.typed = cattr.structure(resp.json(), response_type)
+                        if isinstance(untyped, list):
+                            typed = []
+                            for item in untyped:
+                                typed.append(cattr.structure(item, response_type))
+                            resp.typed = typed
+                        else:
+                            resp.typed = cattr.structure(untyped, response_type)
                     except (TypeError, ValueError, KeyError) as exp:
                         fields = attr.fields_dict(response_type)
                         throw_response_missmatch(fields, resp, exp)
